<?php
/**
 *	Functions file
 *	@package: Horoscop
 *	@since: 2.1.8
 */
$signs = array( 'berbec', 'taur', 'gemeni', 'rac', 'leu', 'fecioara', 'balanta', 'scorpion', 'sagetator', 'capricorn', 'varsator', 'pesti' );
function init_horoscope_settings() {
	/**
	 *	Initiate Horoscop settings after activate plugin
	 *	@since: 2.1.8
	 *	@return: (void)
	 */
	global $wpdb, $signs;
	$query = "CREATE TABLE " . $wpdb->prefix . "horoscope_cache (
		ID smallint(5) unsigned NOT NULL auto_increment,
		sign char(10) NOT NULL,
		content text NOT NULL,
		PRIMARY KEY ID (ID)
		) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci AUTO_INCREMENT=1;";
	require_once ABSPATH . 'wp-admin/includes/upgrade.php';
	dbDelta( $query );
	add_option( 'next_horoscope_cache', 0, '', 'no' );
}

function remove_horoscope_settings() {
	/**
	 *	Remove Horoscop settings after deactivate plugin
	 *	@since: 2.1.8
	 *	@return: (void)
	 */
	global $wpdb;
	$wpdb->query( "DROP TABLE " . $wpdb->prefix . "horoscope_cache" );
	delete_option( 'next_horoscope_cache' );
	delete_option( 'widget_horoscope' );
}

function get_sign_content( $sign ) {
	/**
	 *	Get content of sign from www.acvaria.com
	 *	@since: 2.1.8
	 *	@params: (string) $sign
	 *	@return: (string) $content
	 */
	$curl = curl_init();
	curl_setopt( $curl, CURLOPT_URL, 'http://www.acvaria.com/partener-acvaria.php?z=' . $sign );
	curl_setopt( $curl, CURLOPT_USERAGENT, $_SERVER['HTTP_USER_AGENT'] );
	curl_setopt( $curl, CURLOPT_REFERER, $_SERVER['HTTP_HOST'] );
	curl_setopt( $curl, CURLOPT_RETURNTRANSFER, true );
	curl_setopt( $curl, CURLOPT_HTTPGET, true );
	curl_setopt( $curl, CURLOPT_TIMEOUT, 30 );
	$content = curl_exec( $curl );
	$curl_info = curl_getinfo( $curl );	
	if ( 200 != $curl_info['http_code'] ) return 0;
	curl_close( $curl );
	$content = preg_replace( '/\s\s+/', '', $content );
	$content = str_replace( ' Horoscop oferit de www.acvaria.com', '', strip_tags( $content ) );
	return $content;
}

function make_horoscope_cache() {
	/**
	 *	Make horoscop cache at an interval set, in this case INTERVAL_OF_CACHE defined in horoscope.php
	 *	@since: 2.1.8
	 *	@return: (void)
	 */
	global $wpdb, $signs;
	$i = 0;
	$next_cache = get_option( 'next_horoscope_cache', 0 );
	$no_signs = $wpdb->get_var( 'SELECT COUNT(*) FROM ' . $wpdb->prefix . 'horoscope_cache' );
	if ( $no_signs < 12 || 12 < $no_signs || 0 == (int)$next_cache ) {
		$wpdb->query( 'TRUNCATE TABLE ' . $wpdb->prefix . 'horoscope_cache' );
		while ( $i < 12 ) {
			$sign = $signs[ $i++ ];
			$wpdb->insert( $wpdb->prefix . 'horoscope_cache', array( 'sign' => $sign, 'content' => get_sign_content( $sign ) ), array( '%s', '%s' ) );
		}
		update_option( 'next_horoscope_cache', time() + INTERVAL_OF_CACHE );
	} else if ( $next_cache < time() ) {
		$format_data = array( '%s' );
		while ( $i < 12 ) {
			$sign = $signs[ $i++ ];
			$wpdb->update( $wpdb->prefix . 'horoscope_cache', array( 'content' => get_sign_content( $sign ) ), array( 'sign' => $sign ), $format_data, $format_data );
		}
		update_option( 'next_horoscope_cache', time() + INTERVAL_OF_CACHE );
	}
}

function sign_period( $sign ) {
	/**
	 *	Show the period of every sign
	 *	@since: 1.8.3
	 *	@params: (string) $sign
	 *	@return: (string)
	 */
	switch ( $sign ) {
		case 'berbec':		return '21 martie - 20 aprilie';
		case 'taur':		return '21 aprilie - 21 mai';
		case 'gemeni':		return '22 mai - 21 iunie';
		case 'rac':			return '22 iunie - 22 iulie';
		case 'leu':			return '23 iulie - 22 august';
		case 'fecioara':	return '23 august - 22 septembrie';
		case 'balanta':		return '23 septembrie - 22 octombrie';
		case 'scorpion':	return '23 octombrie - 21 noiembrie';
		case 'sagetator':	return '22 noiembrie - 21 decembrie';
		case 'capricorn':	return '22 decembrie - 19 ianuarie';
		case 'varsator':	return '20 ianuarie - 18 februarie';
		default:			return '19 februarie - 20 martie';
	}
}

function month_translate() {
	/**
	 *	Translate the month of every sign
	 *	@since: 1.8.3
	 *	@return: (string)
	 */
	switch ( date( 'n' ) ) {
		case 1:		return 'ianuarie';
		case 2:		return 'februarie';
		case 3:		return 'martie';
		case 4:		return 'aprilie';
		case 5:		return 'mai';
		case 6:		return 'iunie';
		case 7:		return 'iulie';
		case 8:		return 'august';
		case 9:		return 'septembrie';
		case 10:	return 'octombrie';
		case 11:	return 'moiembrie';
		default:	return 'decembrie';
	}
}
?>